@@ -6,10 +6,10 @@ from dbt.adapters.sql import SQLConnectionManager
 from dbt.logger import GLOBAL_LOGGER as logger
 
 from dataclasses import dataclass
-from typing import Optional
+from typing import Any, Optional, Dict
 from dbt.helper_types import Port
 
-from datetime import datetime
+from datetime import date, datetime
 import decimal
 import re
 import trino
@@ -24,6 +24,9 @@ class TrinoCredentials(Credentials):
     user: str
     password: Optional[str] = None
     method: Optional[str] = None
+    http_headers: Optional[Dict[str, str]] = None
+    http_scheme: Optional[str] = None
+    session_properties: Optional[Dict[str, Any]] = None
     _ALIASES = {
         'catalog': 'database'
     }
@@ -32,6 +35,10 @@ class TrinoCredentials(Credentials):
     def type(self):
         return 'trino'
 
+    @property
+    def unique_field(self):
+        return self.host
+
     def _connection_keys(self):
         return ('host', 'port', 'user', 'database', 'schema')
 
@@ -114,6 +121,9 @@ class ConnectionWrapper(object):
         elif isinstance(value, datetime):
             time_formatted = value.strftime('%Y-%m-%d %H:%M:%S.%f')[:-3]
             return "TIMESTAMP '{}'".format(time_formatted)
+        elif isinstance(value, date):
+            date_formatted = value.strftime('%Y-%m-%d')
+            return "DATE '{}'".format(date_formatted)
         else:
             raise ValueError('Cannot escape {}'.format(type(value)))
 
@@ -154,13 +164,21 @@ class TrinoConnectionManager(SQLConnectionManager):
                 credentials.user,
                 credentials.password,
             )
+            if credentials.http_scheme and credentials.http_scheme != "https":
+                raise dbt.exceptions.RuntimeException(
+                    "http_scheme must be set to 'https' for 'ldap' method."
+                )
             http_scheme = "https"
         elif credentials.method == 'kerberos':
             auth = trino.auth.KerberosAuthentication()
+            if credentials.http_scheme and credentials.http_scheme != "https":
+                raise dbt.exceptions.RuntimeException(
+                    "http_scheme must be set to 'https' for 'kerberos' method."
+                )
             http_scheme = "https"
         else:
             auth = trino.constants.DEFAULT_AUTH
-            http_scheme = "http"
+            http_scheme = credentials.http_scheme or "http"
 
         # it's impossible for trino to fail here as 'connections' are actually
         # just cursor factories.
@@ -171,6 +189,8 @@ class TrinoConnectionManager(SQLConnectionManager):
             catalog=credentials.database,
             schema=credentials.schema,
             http_scheme=http_scheme,
+            http_headers=credentials.http_headers,
+            session_properties=credentials.session_properties,
             auth=auth,
             isolation_level=IsolationLevel.AUTOCOMMIT
         )
